# Changelog

## [0.1.1](https://github.com/mpasson/REMSOL/releases/tag/v0.1.1)

- Published Rust crate at [crates.io](https://crates.io/crates/remsol).
- Documentation available at [docs.rs](https://docs.rs/remsol/latest/remsol/index.html).
- Added docstring in Rust code.
- Passing of complex numbers from Python to Rust is now handles by the `num-complex` crate via `pyo3` and not implemented in the code.
- Minor code improvements.
- Added test CI with Github Actions for both Python and Rust code.

## [0.1.0](https://github.com/mpasson/REMSOL/releases/tag/v0.1.0)

- Initial release.
- Python package available on PyPi.
- Neff calculation using Tranfer Matrix Method.
- Mode calculation using Transfer Matrix Method.
- Neff claculation using Scatterging Matrix Method.
- Documentation for python package at [mpasson.github.io/REMSOL](https://mpasson.github.io/REMSOL/)
